# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Literal

import httpx

from ..types import embedding_create_params
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.embedding_response import EmbeddingResponse

__all__ = ["EmbeddingsResource", "AsyncEmbeddingsResource"]


class EmbeddingsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EmbeddingsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#accessing-raw-response-data-eg-headers
        """
        return EmbeddingsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmbeddingsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#with_streaming_response
        """
        return EmbeddingsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        model: Literal["kanon-2-embedder"],
        texts: Union[SequenceNotStr[str], str],
        dimensions: Optional[int] | Omit = omit,
        overflow_strategy: Optional[Literal["drop_end"]] | Omit = omit,
        task: Optional[Literal["retrieval/query", "retrieval/document"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmbeddingResponse:
        """
        Embed legal texts with an Isaacus legal AI embedder.

        Args:
          model: The ID of the [model](https://docs.isaacus.com/models#embedding) to use for
              embedding.

          texts: The text or array of texts to embed.

              Each text must contain at least one non-whitespace character.

              No more than 128 texts can be embedded in a single request.

          dimensions: A whole number greater than or equal to 1.

          overflow_strategy: The strategy to employ when content exceeds the model's maximum input length.

              `drop_end`, which is the default setting, drops tokens from the end of the
              content exceeding the limit.

              If `null`, an error will be raised if any content exceeds the model's maximum
              input length.

          task: The task the embeddings will be used for.

              `retrieval/query` is meant for queries and statements, and `retrieval/document`
              is meant for anything to be retrieved using query embeddings.

              If `null`, which is the default setting, embeddings will not be optimized for
              any particular task.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/embeddings",
            body=maybe_transform(
                {
                    "model": model,
                    "texts": texts,
                    "dimensions": dimensions,
                    "overflow_strategy": overflow_strategy,
                    "task": task,
                },
                embedding_create_params.EmbeddingCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmbeddingResponse,
        )


class AsyncEmbeddingsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEmbeddingsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEmbeddingsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmbeddingsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#with_streaming_response
        """
        return AsyncEmbeddingsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        model: Literal["kanon-2-embedder"],
        texts: Union[SequenceNotStr[str], str],
        dimensions: Optional[int] | Omit = omit,
        overflow_strategy: Optional[Literal["drop_end"]] | Omit = omit,
        task: Optional[Literal["retrieval/query", "retrieval/document"]] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmbeddingResponse:
        """
        Embed legal texts with an Isaacus legal AI embedder.

        Args:
          model: The ID of the [model](https://docs.isaacus.com/models#embedding) to use for
              embedding.

          texts: The text or array of texts to embed.

              Each text must contain at least one non-whitespace character.

              No more than 128 texts can be embedded in a single request.

          dimensions: A whole number greater than or equal to 1.

          overflow_strategy: The strategy to employ when content exceeds the model's maximum input length.

              `drop_end`, which is the default setting, drops tokens from the end of the
              content exceeding the limit.

              If `null`, an error will be raised if any content exceeds the model's maximum
              input length.

          task: The task the embeddings will be used for.

              `retrieval/query` is meant for queries and statements, and `retrieval/document`
              is meant for anything to be retrieved using query embeddings.

              If `null`, which is the default setting, embeddings will not be optimized for
              any particular task.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/embeddings",
            body=await async_maybe_transform(
                {
                    "model": model,
                    "texts": texts,
                    "dimensions": dimensions,
                    "overflow_strategy": overflow_strategy,
                    "task": task,
                },
                embedding_create_params.EmbeddingCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmbeddingResponse,
        )


class EmbeddingsResourceWithRawResponse:
    def __init__(self, embeddings: EmbeddingsResource) -> None:
        self._embeddings = embeddings

        self.create = to_raw_response_wrapper(
            embeddings.create,
        )


class AsyncEmbeddingsResourceWithRawResponse:
    def __init__(self, embeddings: AsyncEmbeddingsResource) -> None:
        self._embeddings = embeddings

        self.create = async_to_raw_response_wrapper(
            embeddings.create,
        )


class EmbeddingsResourceWithStreamingResponse:
    def __init__(self, embeddings: EmbeddingsResource) -> None:
        self._embeddings = embeddings

        self.create = to_streamed_response_wrapper(
            embeddings.create,
        )


class AsyncEmbeddingsResourceWithStreamingResponse:
    def __init__(self, embeddings: AsyncEmbeddingsResource) -> None:
        self._embeddings = embeddings

        self.create = async_to_streamed_response_wrapper(
            embeddings.create,
        )
